# Objective 1
## Title: Collect and utilize accurate and disaggregated data as a basis for evidence-based policies
## Associated actions
- a. Elaborate and implement a comprehensive strategy for improving migration data at local, national, regional and global levels, with the participation of all relevant stakeholders, under the guidance of the United Nations Statistical Commission, by harmonizing methodologies for data collection, and strengthening analysis and dissemination of migration-related data and indicators.
- b. Improve international comparability and compatibility of migration statistics and national data systems,including by further developing and applying the statistical definition of an international migrant, elaborating a set of standards to measure migrant stocks and flows, and documenting migration patterns and trends, characteristics of migrants,as well as drivers and impacts of migration.
- c. Develop a global programme to build and enhance national capacities in data collection, analysis and dissemination to share data, address data gaps and assess key migration trends, that encourages collaboration between relevant stakeholders at all levels, provides dedicated training financial support and technical assistance, leverages new data sources, including big data, and is reviewed by the United Nations Statistical Commission on a regular basis.
- d. Collect, analyse and use data on the effects and benefits of migration, as well as the contributions of migrants and diasporas to sustainable development, with a view to inform the implementation of the 2030 Agenda for Sustainable Development and related strategies and programmes at the local, national, regional and global levels.
- e. Support further development of and collaboration between existing global and regional databases and depositories, including the IOM Global Migration Data Portal and the World Bank Global Knowledge Partnership on Migration and Development, with a view to systematically consolidate relevant data in a transparent and user-friendly manner, while encouraging inter-agency collaboration to avoid duplication.
- f. Establish and strengthen regional centres for research and training on migration or migration observatories, such as the African Observatory for Migration and Development, to collect and analyse data in line with United Nations standards, including on best practices, the contributions of migrants, the overall economic,social and political benefits and challenges of migration in countries of origin, transit and destination, as well as drivers of migration, with a view to establishing shared strategies and maximizing the value of disaggregated migration data, in coordination with existing regional and subregional mechanisms.
- g. Improve national data collection by integrating migration-related topics in national censuses, as early as practicable, such as on country of birth, country of birth of parents, country of citizenship, country of residence five years prior to the census, most recent arrival date and reason for migrating, to ensure timely analysis and dissemination of results, disaggregated and tabulated in accordance with international standards, for statistical purposes.
- h. Conduct household, labour force and other surveys to collect information on the social and economic integration of migrants or add standard migration modules to existing household surveys to improve national, regional and international comparability, and make collected data available through public-use of statistical microdata files.
- i. Enhance collaboration between State units responsible for migration data and national statistical offices to produce migration-related statistics, including by using administrative records for statistical purposes, such as border records, visa, resident permits, population registers and other relevant sources, while upholding the right to privacy and protecting personal data.
- j. Develop and use country-specific migration profiles, which include disaggregated data on all migration-relevant aspects in a national context, including those on labour market needs, demand and availability of skills, the economic, environmental and social impacts of migration,remittance transfer costs, health, education, occupation,living and working conditions, wages, and the needs of migrants and receiving communities, in order to develop evidence-based migration policies.
- k. Cooperate with relevant stakeholders in countries of origin, transit and destination to develop research, studies and surveys on the interrelationship between migration and the three dimensions of sustainable development, the contributions and skills of migrants and diasporas, as well as their ties to the countries of origin and destination.

# Objective 2
## Title: Minimize the adverse drivers and structural factors that compel people to leave their country of origin
## Associated actions
- a. Promote the implementation of the 2030 Agenda for Sustainable Development, including the Sustainable Development Goals and the Addis Ababa Action Agenda, and the commitment to reach the furthest behind first, as well as the Paris Agreement4 and the Sendai Framework for Disaster Risk Reduction 2015-2030.
- b. Invest in programmes that accelerate States' fulfilment of the Sustainable Development Goals with the aim of eliminating the adverse drivers and structural factors that compel people to leave their country of origin, including through poverty eradication, food security, health and sanitation, education, inclusive economic growth, infrastructure, urban and rural development, employment creation, decent work, gender equality and empowerment of women and girls, resilience and disaster risk reduction, climate change mitigation and adaptation, addressing the socioeconomic effects of all forms of violence, non-discrimination, rule of law and good governance access to justice and protection of human rights, as well as creating and maintaining peaceful and inclusive societies with effective, accountable and transparent institutions.
- c. Establish or strengthen mechanisms to monitor and anticipate the development of risks and threats that might trigger or affect migration movements, strengthen early warning systems, develop emergency procedures and toolkits, launch emergency operations, and support post-emergency recovery, in close cooperation with and support of other States, relevant national and local authorities, National Human Rights Institutions, and civil society.
- d. Invest in sustainable development at local and national levels in all regions allowing all people to improve their lives and meet their aspirations, by fostering sustained, inclusive and sustainable economic growth, including through private and foreign direct investment and trade preferences, to create conducive conditions that allow communities and individuals to take advantage of opportunities in their own countries and drive sustainable development.
- e. Invest in human capital development by promoting entrepreneurship, education, vocational training and skills development programmes and partnerships, productive employment creation, in line with labour market needs, as well as in cooperation with the private sector and trade unions, with a view to reducing youth unemployment, avoiding brain drain and optimizing brain gain in countries of origin, and harnessing the demographic dividend.
- f. Strengthen collaboration between humanitarian and development actors, including by promoting joint analysis, multi-donor approaches and multi-year funding cycles, in order to develop long-term responses and outcomes that ensure respect for the rights of affected individuals,resilience and coping capacities of populations, as well as economic and social self-reliance, and by ensuring these efforts take migration into account.
- g. Account for migrants in national emergency preparedness and response, including by taking into consideration relevant recommendations from State-led consultative processes, such as the Guidelines to Protect Migrants in Countries Experiencing Conflict or Natural Disaster (MICIC Guidelines),
- h. Strengthen joint analysis and sharing of information to better map, understand, predict and address migration movements, such as those that may result from sudden-onset and slow onset natural disasters, the adverse effects of climate change, environmental degradation, as well as other precarious situations, while ensuring the effective respect, protection and fulfilment of the human rights of all migrants.
- i. Develop adaptation and resilience strategies to sudden-onset and slow-onset natural disasters, the adverse effects of climate change, and environmental degradation, such as desertification, land degradation, drought and sea level rise, taking into account the potential implications on migration, while recognizing that adaptation in the country of origin is a priority.
- j. Integrate displacement considerations into disaster preparedness strategies and promote cooperation with neighbouring and other relevant countries to prepare for early warning, contingency planning, stockpiling, coordination mechanisms, evacuation planning, reception and assistance arrangements, and public information.
- k. Harmonize and develop approaches and mechanisms at subregional and regional levels to address the vulnerabilities of persons affected by sudden-onset and slow-onset natural disasters, by ensuring they have access to humanitarian assistance that meets their essential needs with full respect for their rights wherever they are, and by promoting sustainable outcomes that increase resilience and self-reliance, taking into account the capacities of all countries involved.
- l. Develop coherent approaches to address the challenges of migration movements in the context of sudden-onset and slow-onset natural disasters, including by taking into consideration relevant recommendations from State-led consultative processes, such as the Agenda for the Protection of Cross-Border Displaced Persons in the Context of Disasters and Climate Change, and the Platform on Disaster Displacement.

# Objective 3
## Title: Provide accurate and timely information at all stages of migration
## Associated actions
- a. Launch and publicize a centralized and publicly accessible national website to make information available on regular migration options, such as on country-specific immigration laws and policies, visa requirements, application formalities, fees and conversion criteria, employment permit requirements, professional qualification requirements, credential assessment and equivalences, training and study opportunities, and living costs and conditions, in order to inform the decisions of migrants.
- b. Promote and improve systematic bilateral, regional and international cooperation and dialogue to exchange information on migration-related trends, including through joint databases, online training centres and liaison networks, while upholding the right to privacy and protecting personal data.
- c. Establish open and accessible information points along relevant migration routes that can refer migrants to child-sensitive and gender-responsive support and counselling, offer opportunities to communicate with consular representatives of the country of origin, and make available relevant information, including on human rights and fundamental freedoms, appropriate protection and assistance, options and pathways for regular migration, and possibilities for return, in a language the person concerned understands.
- d. Provide newly arrived migrants with targeted, gender-responsive, child-sensitive, accessible and comprehensive information and legal guidance on their rights and obligations, including on compliance with national and local laws, obtaining of work and resident permits, status adjustments, registration with authorities, access to justice to file complaints about rights violations, as well as on access to basic services.
- e. Promote multi-lingual, gender-responsive and evidence-based information campaigns and organize awareness-raising events and pre-departure orientation trainings in countries of origin, in cooperation with local authorities, consular and diplomatic missions, the private sector, academia, migrant and diaspora organizations and civil society, in order to promote safe, orderly and regular migration, as well as to highlight the risks associated with irregular and unsafe migration.

# Objective 4
## Title: Ensure that all migrants have proof of legal identity and adequate documentation
## Associated actions
- a. Improve civil registry systems, with a particular focus on reaching unregistered persons and our nationals residing in other countries, including by providing relevant identity and civil registry documents, strengthening capacities, and investing in information and communication technology solutions, while upholding the right to privacy and protecting personal data.
- b. Harmonize travel documents in line with the specifications of the International Civil Aviation Organization to facilitate interoperable and universal recognition of travel documents, as well as to combat identity fraud and document forgery, including by investing in digitalization, and strengthening mechanisms for biometric data-sharing, while upholding the right to privacy and protecting personal data.
- c. Ensure adequate, timely, reliable and accessible consular documentation to our nationals residing in other countries, including identity and travel documents, making use of information and communications technology, as well as community outreach, particularly in remote areas.
- d. Facilitate access to personal documentation, such as passports and visas, and ensure that relevant regulations and criteria to obtain such documentation are non-discriminatory, by undertaking a gender-responsive and age-sensitive review in order to prevent increased risk of vulnerabilities throughout the migration cycle.
- e. Strengthen measures to reduce statelessness, including by registering migrants' births, ensuring that women and men can equally confer their nationality to their children, and providing nationality to children born in another State's territory, especially in situations where a child would otherwise be stateless, fully respecting the human right to a nationality and in accordance with national legislation.
- f. Review and revise requirements to prove nationality at service delivery centres to ensure that migrants without proof of nationality or legal identity are not precluded from accessing basic services nor denied their human rights.
- g. Build upon existing practices at the local level that facilitate participation in community life, such as interaction with authorities and access to relevant services, through the issuance of registration cards to all persons living in a municipality, including migrants, that contain basic personal information, while not constituting entitlements to citizenship or residency.

# Objective 5
## Title: Enhance availability and flexibility of pathways for regular migration
## Associated actions
- a. Develop human rights-based and gender-responsive bilateral, regional and multilateral labour mobility agreements with sector-specific standard terms of employment in cooperation with relevant stakeholders, drawing on relevant ILO standards, guidelines and principles, in compliance with international human rights and labour law.
- b. Facilitate regional and cross-regional labour mobility through international and bilateral cooperation arrangements, such as free movement regimes, visa liberalization or multiple country visas, and labour mobility cooperation frameworks, in accordance with national priorities, local market needs and skills supply.
- c. Review and revise existing options and pathways for regular migration, with a view to optimize skills matching in labour markets, address demographic realities and development challenges and opportunities, in accordance with local and national labour market demands and skills supply, in consultation with the private sector and other relevant stakeholders.
- d. Develop flexible, rights-based and gender-responsive labour mobility schemes for migrants, in accordance with local and national labour market needs and skills supply at all skills levels, including temporary, seasonal, circular, and fast-track programmes in areas of labour shortages, by providing flexible, convertible and non-discriminatory visa and permit options, such as for permanent and temporary work, multiple-entry study, business, visit, investment and entrepreneurship.
- e. Promote effective skills matching in the national economy by involving local authorities and other relevant stakeholders, particularly the private sector and trade unions, in the analysis of the local labour market, identification of skills gaps, definition of required skills profiles, and evaluation of the efficacy of labour migration policies, in order to ensure market-responsive contractual labour mobility through regular pathways.
- f. Foster efficient and effective skills-matching programmes by reducing visa and permit processing timeframes for standard employment authorizations, and by offering accelerated and facilitated visa and permit processing for employers with a track record of compliance.
- g. Develop or build on existing national and regional practices for admission and stay of appropriate duration based on compassionate, humanitarian or other considerations for migrants compelled to leave their countries of origin, due to sudden-onset natural disasters and other precarious situations, such as by providing humanitarian visas, private sponsorships, access to education for children, and temporary work permits, while adaptation in or return to their country of origin is not possible.
- h. Cooperate to identify, develop and strengthen solutions for migrants compelled to leave their countries of origin due to slow-onset natural disasters, the adverse effects of climate change, and environmental degradation, such as desertification, land degradation, drought and sea level rise, including by devising planned relocation and visa options, in cases where adaptation in or return to their country of origin is not possible.
- i. Facilitate access to procedures for family reunification for migrants at all skills levels through appropriate measures that promote the realization of the right to family life and the best interests of the child, including by reviewing and revising applicable requirements, such as on income, language proficiency, length of stay, work authorization, and access to social security and services.
- j. Expand available options for academic mobility, including through bilateral and multilateral agreements that facilitate academic exchanges, such as scholarships for students and academic professionals, visiting professorships, joint training programmes, and international research opportunities, in cooperation with academic institutions and other relevant stakeholders.

# Objective 6
## Title: Facilitate Fair And Ethical Recruitment And Safeguard Conditions That Ensure Decent Work
## Associated actions
- a. Promote signature, ratification, accession and implementation of relevant international instruments related to international labour migration, labour rights, decent work and forced labour.
- b. Build upon the work of existing bilateral, subregional and regional platforms that have overcome obstacles and identified best practices in labour mobility, by facilitating cross-regional dialogue to share this knowledge, and to promote the full respect for the human and labour rights of migrant workers at all skills levels, including migrant domestic workers.
- c. Improve regulations on public and private recruitment agencies, in order to align them with international guidelines and best practices, prohibit recruiters and employers from charging or shifting recruitment fees or related costs to migrant workers in order to prevent debt bondage, exploitation and forced labour, including by establishing mandatory, enforceable mechanisms for effective regulation and monitoring of the recruitment industry.
- d. Establish partnerships with all relevant stakeholders, including employers, migrant workers organizations and trade unions, to ensure that migrant workers are provided written contracts and are made aware of the provisions therein, the regulations relating to international labour recruitment and employment in the country of destination, their rights and obligations, as well as on how to access effective complaint and redress mechanisms, in a language they understand.
- e. Enact and implement national laws that sanction human and labour rights violations, especially in cases of forced and child labour, and cooperate with the private sector, including employers, recruiters, subcontractors and suppliers, to build partnerships that promote conditions for decent work, prevent abuse and exploitation, and ensure that the roles and responsibilities within the recruitment and employment processes are clearly outlined, thereby enhancing supply chain transparency.
- f. Strengthen the enforcement of fair and ethical recruitment and decent work norms and policies by enhancing the abilities of labour inspectors and other authorities to better monitor recruiters, employers and service providers in all sectors, ensuring that international human rights and labour law is observed to prevent all forms of exploitation, slavery, servitude, and forced, compulsory or child labour.
- g. Develop and strengthen labour migration and fair and ethical recruitment processes that allow migrants to change employers and modify the conditions or length of their stay with minimal administrative burden, while promoting greater opportunities for decent work and respect for international human rights and labour law.
- h. Take measures that prohibit the confiscation or non-consensual retention of work contracts, and travel or identity documents from migrants, in order to prevent abuse, all forms of exploitation, forced, compulsory and child labour, extortion and other situations of dependency, and to allow migrants to fully exercise their human rights.
- i. Provide migrant workers engaged in remunerated and contractual labour with the same labour rights and protections extended to all workers in the respective sector, such as the rights to just and favourable conditions of work, to equal pay for work of equal value, to freedom of peaceful assembly and association, and to the highest attainable standard of physical and mental health, including through wage protection mechanisms, social dialogue and membership in trade unions.
- j. Ensure migrants working in the informal economy have safe access to effective reporting, complaint, and redress mechanisms in cases of exploitation, abuse or violations of their rights in the workplace, in a manner that does not exacerbate vulnerabilities of migrants that denounce such incidents and allow them to participate in respective legal proceedings whether in the country of origin or destination.
- k. Review relevant national labour laws, employment policies and programmes to ensure that they include considerations of the specific needs and contributions of women migrant workers, especially in domestic work and lower-skilled occupations, and adopt specific measures to prevent, report, address and provide effective remedy for all forms of exploitation and abuse, including sexual and gender-based violence, as a basis to promote gender-responsive labour mobility policies.
- l. Develop and improve national policies and programmes relating to international labour mobility, including by taking into consideration relevant recommendations of the ILO General Principles and Operational Guidelines for Fair Recruitment, the United Nations Guiding Principles on Business and Human Rights, and the IOM International Recruitment Integrity System (IRIS).

# Objective 7
## Title: Address and Reduce Vulnerabilities in Migration
## Associated actions
- a. Review relevant policies and practices to ensure they do not create, exacerbate or unintentionally increase vulnerabilities of migrants, including by applying a human rights-based, gender- and disability-responsive, as well as an age- and child-sensitive approach.
- b. Establish comprehensive policies and develop partnerships that provide migrants in a situation of vulnerability, regardless of their migration status, with necessary support at all stages of migration, through identification and assistance, as well as protection of their human rights, in particular in cases related to women at risk, children, especially those unaccompanied or separated from their families, members of ethnic and religious minorities, victims of violence, including sexual and gender-based violence, older persons, persons with disabilities, persons who are discriminated against on any basis, indigenous peoples, workers facing exploitation and abuse, domestic workers, victims of trafficking in persons, and migrants subject to exploitation and abuse in the context of smuggling of migrants.
- c. Develop gender-responsive migration policies to address the particular needs and vulnerabilities of migrant women, girls and boys, which may include assistance, health care, psychological and other counselling services, as well as access to justice and effective remedies, especially in cases of sexual and gender-based violence, abuse and exploitation.
- d. Review relevant existing labour laws and work conditions to identify and effectively address workplace-related vulnerabilities and abuses of migrant workers at all skills levels, including domestic workers, and those working in the informal economy, in cooperation with relevant stakeholders, particularly the private sector.
- e. Account for migrant children in national child protection systems by establishing robust procedures for the protection of migrant children in relevant legislative, administrative and judicial proceedings and decisions, as well as in all migration policies and programmes that impact children, including consular protection policies and services, as well as cross-border cooperation frameworks, in order to ensure the best interests of the child are appropriately integrated, consistently interpreted and applied in coordination and cooperation with child protection authorities.
- f. Protect unaccompanied and separated children at all stages of migration through the establishment of specialized procedures for their identification, referral, care and family reunification, and provide access to health care services, including mental health, education, legal assistance and the right to be heard in administrative and judicial proceedings, including by swiftly appointing a competent and impartial legal guardian, as essential means to address their particular vulnerabilities and discrimination, protect them from all forms of violence, and provide access to sustainable solutions that are in their best interests.
- g. Ensure migrants have access to public or affordable independent legal assistance and representation in legal proceedings that affect them, including during any related judicial or administrative hearing, in order to safeguard that all migrants, everywhere, are recognized as persons before the law and that the delivery of justice is impartial and non-discriminatory.
- h. Develop accessible and expedient procedures that facilitate transitions from one status to another and inform migrants of their rights and obligations, so as to prevent migrants from falling into an irregular status in the country of destination, to reduce precariousness of status and related vulnerabilities, as well as to enable individual status assessments for migrants, including for those who have fallen out of regular status, without fear of arbitrary expulsion.
- i. Build on existing practices to facilitate access for migrants in an irregular status to an individual assessment that may lead to regular status, on a case by case basis and with clear and transparent criteria, especially in cases where children, youth and families are involved, as an option to reduce vulnerabilities, as well as for States to ascertain better knowledge of the resident population.
- j. Apply specific support measures to ensure that migrants caught up in situations of crisis in countries of transit and destination have access to consular protection and humanitarian assistance, including by facilitating cross-border and broader international cooperation, as well as by taking migrant populations into account in crisis preparedness, emergency response and post-crisis action.
- k. Involve local authorities and relevant stakeholders in the identification, referral and assistance of migrants in a situation of vulnerability, including through agreements with national protection bodies, legal aid and service providers, as well as the engagement of mobile response teams, where they exist.
- l. Develop national policies and programmes to improve national responses that address the needs of migrants in situations of vulnerability, including by taking into consideration relevant recommendations of the Global Migration Group Principles and Guidelines, Supported by Practical Guidance, on the Human Rights Protection of Migrants in Vulnerable Situations.

# Objective 8
## Title: Save Lives and Establish Coordinated International Efforts on Missing Migrants
## Associated actions
- a. Develop procedures and agreements on search and rescue of migrants, with the primary objective to protect migrants' right to life that uphold the prohibition of collective expulsion, guarantee due process and individual assessments, enhance reception and assistance capacities, and ensure that the provision of assistance of an exclusively humanitarian nature for migrants is not considered unlawful.
- b. Review the impacts of migration-related policies and laws to ensure that these do not raise or create the risk of migrants going missing, including by identifying dangerous transit routes used by migrants, by working with other States as well as relevant stakeholders and international organizations to identify contextual risks and establishing mechanisms for preventing and responding to such situations, with particular attention to migrant children, especially those unaccompanied or separated.
- c. Enable migrants to communicate with their families without delay to inform them that they are alive by facilitating access to means of communication along routes and at their destination, including in places of detention, as well as access to consular missions, local authorities and organizations that can provide assistance with family contacts, especially in cases of unaccompanied or separated migrant children, as well as adolescents.
- d. Establish transnational coordination channels, including through consular cooperation, and designate contact points for families looking for missing migrants, through which families can be kept informed on the status of the search and obtain other relevant information, while respecting the right to privacy and protecting personal data.
- e. Collect, centralize and systematize data regarding corpses and ensure traceability after burial, in accordance with internationally accepted forensic standards, and establish coordination channels at transnational level to facilitate identification and the provision of information to families.
- f. Make all efforts, including through international cooperation, to recover, identify and repatriate the remains of deceased migrants to their countries of origin, respecting the wishes of grieving families, and, in the case of unidentified individuals, facilitate the identification and subsequent recovery of the mortal remains, ensuring that the remains of deceased migrants are treated in a dignified, respectful and proper manner.

# Objective 9
## Title: Strengthen the transnational response to smuggling of migrants
## Associated actions
- a. Promote ratification, accession and implementation of the Protocol against the Smuggling of Migrants by Land, Sea and Air, supplementing the United Nations Convention against Transnational Organised Crime (UNTOC).
- b. Use transnational, regional and bilateral mechanisms to share relevant information and intelligence on smuggling routes, modus operandi and financial transactions of smuggling networks, vulnerabilities faced by smuggled migrants, and other data to dismantle the smuggling networks and enhance joint responses.
- c. Develop gender-responsive and child-sensitive cooperation protocols along migration routes that outline step-by-step measures to adequately identify and assist smuggled migrants, in accordance with international law, as well as to facilitate cross-border law enforcement and intelligence cooperation in order to prevent and counter smuggling of migrants with the aim to end impunity for smugglers and prevent irregular migration, while ensuring that counter-smuggling measures are in full respect for human rights.
- d. Adopt legislative and other measures as may be necessary to establish the smuggling of migrants as a criminal offence, when committed intentionally and in order to obtain, directly or indirectly, a financial or other material benefit for the smuggler, and include enhanced penalties for smuggling of migrants under aggravating circumstances, in accordance with international law.
- e. Design, review or amend relevant policies and procedures to distinguish between the crimes of smuggling of migrants and trafficking in persons by using the correct definitions and applying distinct responses to these separate crimes, while recognizing that smuggled migrants might also become victims of trafficking in persons, therefore requiring appropriate protection and assistance.
- f. Take measures to prevent the smuggling of migrants along the migration cycle in partnership with other States and relevant stakeholders, including by cooperating in the fields of development, public information, justice, as well as training and technical capacity building at national and local levels, paying special attention to geographic areas from where irregular migration systematically originates.

# Objective 10
## Title: Prevent, Combat And Eradicate Trafficking In Persons In The Context Of International Migration
## Associated actions
- a. Promote, ratification, accession and implementation of the Protocol to Prevent, Suppress and Punish Trafficking in Persons Especially Women and Children, supplementing the United Nations Convention against Transnational Organized Crime (UNTOC).
- b. Promote the implementation of the Global Plan of Action to Combat Trafficking in Persons and take into consideration relevant recommendations of the UNODC Toolkit to Combat Trafficking in Persons and other relevant UNODC documents when developing and implementing national and regional policies and measures relating to trafficking in persons.
- c. Monitor irregular migration routes which may be exploited by human trafficking networks to recruit and victimize smuggled or irregular migrants, in order to strengthen cooperation at bilateral, regional and cross-regional levels on prevention, investigation, and prosecution of perpetrators, as well as on identification of, and protection and assistance to victims of trafficking in persons.
- d. Share relevant information and intelligence through transnational and regional mechanisms, including on the modus operandi, economic models and conditions driving trafficking networks, strengthen cooperation between all relevant actors, including financial intelligence units, regulators and financial institutions, to identify and disrupt financial flows associated with trafficking in persons, and enhance judicial cooperation and enforcement with the aim to ensure accountability and end impunity.
- e. Apply measures that address the particular vulnerabilities of women, men, girls and boys, regardless of their migration status, that have become or are at risk of becoming victims of trafficking in persons and other forms of exploitation by facilitating access to justice and safe reporting without fear of detention, deportation or penalty, focusing on prevention, identification, appropriate protection and assistance, and addressing specific forms of abuse and exploitation.
- f. Ensure that definitions of trafficking in persons used in legislation, migration policy and planning, as well as in judicial prosecutions are in accordance with international law, in order to distinguish between the crimes of trafficking in persons and smuggling of migrants.
- g. Strengthen legislation and relevant procedures to enhance prosecution of traffickers, avoid criminalization of migrants who are victims of trafficking in persons for trafficking-related offences, and ensure that the victim receives appropriate protection and assistance, not conditional upon cooperation with the authorities against suspected traffickers.
- h. Provide migrants that have become victims of trafficking in persons with protection and assistance, such as measures for physical, psychological and social recovery, as well as measures that permit them to remain in the country of destination, temporarily or permanently, in appropriate cases, facilitating victims' access to justice, including redress and compensation, in accordance with international law.
- i. Create national and local information systems and training programmes which alert and educate citizens, employers, as well as public officials and law enforcement officers, and strengthen capacities to identify signs of trafficking in persons, such as forced, compulsory or child labour, in countries of origin, transit and destination.
- j. Invest in awareness-raising campaigns, in partnership with relevant stakeholders, for migrants and prospective migrants on the risks and dangers of trafficking in persons, and provide them with information on preventing and reporting trafficking activities.

# Objective 11
## Title: Manage Borders In An Integrated, Secure And Coordinated Manner
## Associated actions
- a. Enhance international, regional and cross-regional border management cooperation, taking into consideration the particular situation of countries of transit, on proper identification, timely and efficient referral, assistance and appropriate protection of migrants in situations of vulnerability at or near international borders, in compliance with international human rights law, by adopting whole-of-government approaches, implementing joint cross-border trainings, and fostering capacity-building measures.
- b. Establish appropriate structures and mechanisms for effective integrated border management by ensuring comprehensive and efficient border crossing procedures, including through pre-screening of arriving persons, pre-reporting by carriers of passengers, and use of information and communication technology, while upholding the principle of non-discrimination, respecting the right to privacy and protecting personal data.
- c. Review and revise relevant national procedures for border screening, individual assessment and interview processes to ensure due process at international borders and that all migrants are treated in accordance with international human rights law, including through cooperation with National Human Rights Institutions and other relevant stakeholders.
- d. Develop technical cooperation agreements that enable States to request and offer assets, equipment and other technical assistance to strengthen border management, particularly in the area of search and rescue as well as other emergency situations.
- e. Ensure that child protection authorities are promptly informed and assigned to participate in procedures for the determination of the best interests of the child once an unaccompanied or separated child crosses an international border, in accordance with international law, including by training border officials in the rights of the child and child-sensitive procedures, such as those that prevent family separation and reunite families when family separation occurs.
- f. Review and revise relevant laws and regulations to determine whether sanctions are appropriate to address irregular entry or stay and, if so, to ensure that they are proportionate, equitable, non-discriminatory, and fully consistent with due process and other obligations under international law.
- g. Improve cross-border collaboration among neighbouring and other States relating to the treatment given to persons crossing or seeking to cross international borders, including by taking into consideration relevant recommendations from the OHCHR Recommended Principles and Guidelines on Human Rights at International Borders when identifying best practices.

# Objective 12
## Title: Strengthen Certainty And Predictability In Migration Procedures For Appropriate Screening, Assessment And Referral
## Associated actions
- a. Increase transparency and accessibility of migration procedures by communicating the requirements for entry, admission, stay, work, study or other activities, and introducing technology to simplify application procedures, in order to avoid unnecessary delays and expenses for States and migrants.
- b. Develop and conduct intra- and cross-regional specialized human rights and trauma informed trainings for first responders and government officials, including law enforcement authorities, border officials, consular representatives and judicial bodies, to facilitate and standardize identification and referral of, as well as appropriate assistance and counselling in a culturally-sensitive way, to victims of trafficking in persons, migrants in situations of vulnerability, including children, in particular those unaccompanied or separated, and persons affected by any form of exploitation and abuse related to smuggling of migrants under aggravating circumstances.
- c. Establish gender-responsive and child-sensitive referral mechanisms, including improved screening measures and individual assessments at borders and places of first arrival, by applying standardized operating procedures developed in coordination with local authorities, National Human Rights Institutions, international organizations and civil society.
- d. Ensure that migrant children are promptly identified at places of first arrival in countries of transit and destination, and, if unaccompanied or separated, are swiftly referred to child protection authorities and other relevant services as well as appointed a competent and impartial legal guardian, that family unity is protected, and that anyone legitimately claiming to be a child is treated as such unless otherwise determined through a multi-disciplinary, independent and child-sensitive age assessment.
- e. Ensure that, in the context of mixed movements, relevant information on rights and obligations under national laws and procedures, including on entry and stay requirements, available forms of protection, as well as options for return and reintegration, is appropriately, timely and effectively communicated, and accessible.

# Objective 13
## Title: Use Migration Detention Only As A Measure Of Last Resort And Work Towards Alternatives
## Associated actions
- a. Use existing relevant human rights mechanisms to improve independent monitoring of migrant detention, ensuring that it is a measure of last resort, that human rights violations do not occur, and that States promote, implement and expand alternatives to detention, favouring non-custodial measures and community-based care arrangements, especially in the case of families and children.
- b. Consolidate a comprehensive repository to disseminate best practices of human rights based alternatives to detention in the context of international migration, including by facilitating regular exchanges and the development of initiatives based on successful practices among States, and between States and relevant stakeholders.
- c. Review and revise relevant legislation, policies and practices related to immigration detention to ensure that migrants are not detained arbitrarily, that decisions to detain are based on law, are proportionate, have a legitimate purpose, and are taken on an individual basis, in full compliance with due process and procedural safeguards, and that immigration detention is not promoted as a deterrent or used as a form of cruel, inhumane or degrading treatment to migrants, in accordance with international human rights law.
- d. Provide access to justice for all migrants in countries of transit and destination that are or may be subject to detention, including by facilitating access to free or affordable legal advice and assistance of a qualified and independent lawyer, as well as access to information and the right to regular review of a detention order.
- e. Ensure that all migrants in detention are informed about the reasons for their detention, in a language they understand, and facilitate the exercise of their rights, including to communicate with the respective consular or diplomatic missions without delay, legal representatives and family members, in accordance with international law and due process guarantees.
- f. Reduce the negative and potentially lasting effects of detention on migrants by guaranteeing due process and proportionality, that it is for the shortest period of time, safeguards physical and mental integrity, and that, as a minimum, access to food, basic healthcare, legal orientation and assistance, information and communication, as well as adequate accommodation is granted, in accordance with international human rights law.
- g. Ensure that all governmental authorities and private actors duly charged with administering immigration detention do so in a way consistent with human rights and are trained on non-discrimination, the prevention of arbitrary arrest and detention in the context of international migration, and are held accountable for violations or abuses of human rights.
- h. Protect and respect the rights and best interests of the child at all times, regardless of their migration status, by ensuring availability and accessibility of a viable range of alternatives to detention in non-custodial contexts, favouring community-based care arrangements, that ensure access to education and healthcare, and respect their right to family life and family unity, and by working to end the practice of child detention in the context of international migration.

# Objective 14
## Title: Enhance Consular Protection, Assistance And Cooperation Throughout The Migration Cycle
## Associated actions
- a. Cooperate to build consular capacities, train consular officers, promote arrangements for providing consular services collectively where individual States lack capacity, including through technical assistance, and to develop bilateral or regional agreements on various aspects of consular cooperation.
- b. Involve relevant consular and immigration personnel in existing global and regional fora on migration in order to exchange information and best practices about issues of mutual concern that pertain to citizens abroad and contribute to comprehensive and evidence-based migration policy development.
- c. Conclude bilateral or regional agreements on consular assistance and representation in places where States have an interest in strengthening effective consular services related to migration, but do not have a diplomatic or consular presence.
- d. Strengthen consular capacities in order to identify, protect and assist our nationals abroad who are in a situation of vulnerability, including victims of human and labour rights violations or abuse, victims of crime, victims of trafficking in persons, migrants subject to smuggling under aggravating circumstances, and migrant workers exploited in the process of recruitment, by providing training to consular officers on human rights-based, gender-responsive and child-sensitive actions in this regard.
- e. Provide our nationals abroad the opportunity to register with the country of origin, in close cooperation with consular, national and local authorities, as well as relevant migrant organizations, as a means to facilitate information, services and assistance to migrants in emergency situations and ensure migrants' accessibility to relevant and timely information, such as by establishing helplines and consolidating national digital databases, while upholding the right to privacy and protecting personal data.
- f. Provide consular support to our nationals through advice, including on local laws and customs, interaction with authorities, financial inclusion, and business establishment, as well as through the issuance of relevant documentation, such as travel documents, and consular identity documents that may facilitate access to services, assistance in emergency situations, the opening of a bank account, and access to remittance facilities.

# Objective 15
## Title: Provide access to basic services for migrants
## Associated actions
- a. Enact laws and take measures to ensure that service delivery does not amount to discrimination against migrants on the grounds of race, colour, sex, language, religion, political or other opinion, national or social origin, property, birth, disability or other grounds irrespective of cases where differential provision of services based on migration status might apply.
- b. Ensure that cooperation between service providers and immigration authorities does not exacerbate vulnerabilities of irregular migrants by compromising their safe access to basic services or unlawfully infringing upon the human rights to privacy, liberty and security of person at places of basic service delivery.
- c. Establish and strengthen holistic and easily accessible service points at local level, that are migrant inclusive, offer relevant information on basic services in a gender and disability-responsive as well as child-sensitive manner, and facilitate safe access thereto.
- d. Establish or mandate independent institutions at the national or local level, such as National Human Rights Institutions, to receive, investigate and monitor complaints about situations in which migrants' access to basic services is systematically denied or hindered, facilitate access to redress, and work towards a change in practice.
- e. Incorporate the health needs of migrants in national and local health care policies and plans, such as by strengthening capacities for service provision, facilitating affordable and non-discriminatory access, reducing communication barriers, and training health care providers on culturally-sensitive service delivery, in order to promote physical and mental health of migrants and communities overall, including by taking into consideration relevant recommendations from the WHO Framework of Priorities and Guiding Principles to Promote the Health of Refugees and Migrants.
- f. Provide inclusive and equitable quality education to migrant children and youth, as well as facilitate access to lifelong learning opportunities, including by strengthening the capacities of education systems and by facilitating non-discriminatory access to early childhood development, formal schooling, non-formal education programmes for children for whom the formal system is inaccessible, on-the-job and vocational training, technical education, and language training, as well as by fostering partnerships with all stakeholders that can support this endeavour.

# Objective 16
## Title: Empower Migrants And Societies To Realize Full Inclusion And Social Cohesion
## Associated actions
- a. Promote mutual respect for the cultures, traditions and customs of communities of destination and of migrants by exchanging and implementing best practices on integration policies, programmes and activities, including on ways to promote acceptance of diversity and facilitate social cohesion and inclusion.
- b. Establish comprehensive and needs-based pre-departure and post-arrival programmes that may include rights and obligations, basic language training, as well as orientation about social norms and customs in the country of destination.
- c. Develop national short, medium and long term policy goals regarding the inclusion of migrants in societies, including on labour market integration, family reunification, education, non-discrimination and health, including by fostering partnerships with relevant stakeholders.
- d. Work towards inclusive labour markets and full participation of migrant workers in the formal economy by facilitating access to decent work and employment for which they are most qualified, in accordance with local and national labour market demands and skills supply.
- e. Empower migrant women by eliminating gender-based discriminatory restrictions on formal employment, ensuring the right to freedom of association, and facilitating access to relevant basic services, as measures to promote their leadership and guarantee their full, free and equal participation in society and the economy.
- f. Establish community centres or programmes at the local level to facilitate migrant participation in the receiving society by involving migrants, community members, diaspora organizations, migrant associations, and local authorities in intercultural dialogue, sharing of stories, mentorship programmes, and development of business ties that improve integration outcomes and foster mutual respect.
- g. Capitalize on the skills, cultural and language proficiency of migrants and receiving communities by developing and promoting peer-to-peer training exchanges, gender-responsive, vocational and civic integration courses and workshops.
- h. Support multicultural activities through sports, music, arts, culinary festivals, volunteering and other social events that will facilitate mutual understanding and appreciation of migrant cultures and those of destination communities.
- i. Promote school environments that are welcoming and safe, and support the aspirations of migrant children by enhancing relationships within the school community, incorporating evidence-based information about migration in education curricula, and dedicating targeted resources to schools with a high concentration of migrant children for integration activities in order to promote respect for diversity and inclusion, and to prevent all forms discrimination, including racism, xenophobia and intolerance.

# Objective 17
## Title: Eliminate All Forms Of Discrimination And Promote Evidence-Based Public Discourse To Shape Perceptions Of Migration
## Associated actions
- a. Enact, implement or maintain legislation that penalizes hate crimes and aggravated hate crimes targeting migrants, and train law enforcement and other public officials to identify, prevent and respond to such crimes and other acts of violence that target migrants, as well as to provide medical, legal and psychosocial assistance for victims.
- b. Empower migrants and communities to denounce any acts of incitement to violence directed towards migrants by informing them of available mechanisms for redress, and ensure that those who actively participate in the commission of a hate crime targeting migrants are held accountable, in accordance with national legislation, while upholding international human rights law, in particular the right to freedom of expression.
- c. Promote independent, objective and quality reporting of media outlets, including internet based information, including by sensitizing and educating media professionals on migration-related issues and terminology, investing in ethical reporting standards and advertising, and stopping allocation of public funding or material support to media outlets that systematically promote intolerance, xenophobia, racism and other forms of discrimination towards migrants, in full respect for the freedom of the media.
- d. Establish mechanisms to prevent, detect and respond to racial, ethnic and religious profiling of migrants by public authorities, as well as systematic instances of intolerance, xenophobia, racism and all other multiple and intersecting forms of discrimination in partnership with National Human Rights Institutions, including by tracking and publishing trends analyses, and ensuring access to effective complaint and redress mechanisms.
- e. Provide migrants, especially migrant women, with access to national and regional complaint and redress mechanisms with a view to promoting accountability and addressing governmental actions related to discriminatory acts and manifestations carried out against migrants and their families.
- f. Promote awareness-raising campaigns targeted at communities of origin, transit and destination in order to inform public perceptions regarding the positive contributions of safe, orderly and regular migration, based on evidence and facts, and to end racism, xenophobia and stigmatization against all migrants.
- g. Engage migrants, political, religious and community leaders, as well as educators and service providers to detect and prevent incidences of intolerance, racism, xenophobia, and other forms of discrimination against migrants and diasporas and support activities in local communities to promote mutual respect, including in the context of electoral campaigns.

# Objective 18
## Title: Invest In Skills Development And Facilitate Mutual Recognition Of Skills, Qualifications And Competences
## Associated actions
- a. Develop standards and guidelines for the mutual recognition of foreign qualifications and non-formally acquired skills in different sectors in collaboration with the respective industries with a view to ensuring worldwide compatibility based on existing models and best practices.
- b. Promote transparency of certifications and compatibility of National Qualifications Frameworks by agreeing on standard criteria, indicators and assessment parameters, and by creating and strengthening national skills profiling tools, registries or institutions in order to facilitate effective and efficient mutual recognition procedures at all skills levels.
- c. Conclude bilateral, regional or multilateral mutual recognition agreements or include recognition provisions in other agreements, such as labour mobility or trade agreements, in order to provide equivalence or comparability in national systems, such as automatic or managed mutual recognition mechanisms.
- d. Use technology and digitalization to evaluate and mutually recognize skills more comprehensively based on formal credentials as well as non-formally acquired competences and professional experience at all skills levels.
- e. Build global skills partnerships amongst countries that strengthen training capacities of national authorities and relevant stakeholders, including the private sector and trade unions, and foster skills development of workers in countries of origin and migrants in 26 countries of destination with a view to preparing trainees for employability in the labour markets of all participating countries.
- f. Promote inter-institutional networks and collaborative programmes for partnerships between the private sector and educational institutions in countries of origin and destination to enable mutually beneficial skills development opportunities for migrants, communities and participating partners, including by building on the best practices of the Business Mechanism developed in the context of the Global Forum on Migration and Development.
- g. Engage in bilateral partnerships and programmes in cooperation with relevant stakeholders that promote skills development, mobility and circulation, such as student exchange programmes, scholarships, professional exchange programmes and trainee- or apprenticeships that include options for beneficiaries, after successful completion of these programmes, to seek employment and engage in entrepreneurship.
- h. Cooperate with the private sector and employers to make available easily accessible and gender-responsive remote or online skills development and matching programmes to migrants at all skills levels, including early and occupation-specific language training, on the-job training and access to advanced training programmes, to enhance their employability in sectors with demand for labour based on the industry's knowledge of labour market dynamics, especially to promote the economic empowerment of women.
- i. Enhance the ability of migrant workers to transition from a job or employer to another by making available documentation that recognizes skills acquired on the job or through training in order to optimize the benefits of upskilling.
- j. Develop and promote innovative ways to mutually recognize and assess formally and informally acquired skills, including through timely and complementary training to job seekers, mentoring, and internship programmes in order to fully recognize existing credentials and provide certificates of proficiency for the validation of newly acquired skills.
- k. Establish screening mechanisms of credentials and offer information to migrants on how to get their skills and qualifications assessed and recognized prior to departure, including in recruitment processes or at an early stage after arrival to improve employability.
- l. Cooperate to promote documentation and information tools, in partnership with relevant stakeholders, that provide an overview of a worker's credentials, skills and qualifications, recognized in countries of origin, transit and destination, in order to enable employers to evaluate the suitability of migrant workers in job application processes.

# Objective 19
## Title: Create Conditions For Migrants And Diasporas To Fully Contribute To Sustainable Development In All Countries
## Associated actions
- a. Ensure the full and effective implementation of the 2030 Agenda for Sustainable Development and the Addis Ababa Action Agenda by fostering and facilitating the positive effects of migration for the realization of all Sustainable Development Goals.
- b. Integrate migration into development planning and sectoral policies at local, national, regional and global levels, taking into consideration relevant existing policy guidelines and recommendations, such as the GMG Handbook on Mainstreaming Migration into Development Planning, in order to strengthen policy coherence and effectiveness of development cooperation.
- c. Invest in research on the impact of non-financial contributions of migrants and diasporas to sustainable development in countries of origin and destination, such as knowledge and skills transfer, social and civic engagement, and cultural exchange, with a view to developing evidence-based policies and strengthening global policy discussions.
- d. Facilitate the contributions of migrants and diasporas to their countries of origin, including by establishing or strengthening government structures or mechanisms at all levels, such as dedicated diaspora offices or focal points, diaspora policy advisory boards for governments to account for the potential of migrants and diasporas in migration and development policy-making, and dedicated diaspora focal points in diplomatic or consular missions.
- e. Develop targeted support programmes and financial products that facilitate migrant and diaspora investments and entrepreneurship, including by providing administrative and legal support in business creation, granting seed capital-matching, establish diaspora bonds and diaspora development funds, investment funds, and organize dedicated trade fairs.
- f. Provide easily accessible information and guidance, including through digital platforms, as well as tailored mechanisms for the coordinated and effective financial, voluntary or philanthropic engagement of migrants and diasporas, especially in humanitarian emergencies in their countries of origin, including by involving consular missions.
- g. Enable political participation and engagement of migrants in their countries of origin, including in peace and reconciliation processes, in elections and political reforms, such as by establishing voting registries for citizens abroad, and by parliamentary representation, in accordance with national legislation.
- h. Promote migration policies that optimize the benefits of diasporas for countries of origin and destination and their communities, by facilitating flexible modalities to travel, work and invest with minimal administrative burdens, including by reviewing and revising visa, residency and citizenship regulations, as appropriate.
- i. Cooperate with other States, the private sector and employers organizations to enable migrants and diasporas, especially those in highly technical fields and in high demand, to carry out some of their professional activities and engage in knowledge transfer in their home countries, without necessarily losing employment, residence status, or earned social benefits.
- j. Build partnerships between local authorities, local communities, the private sector, diasporas, hometown associations and migrant organizations to promote knowledge and skills transfer between their countries of origin and countries of destination, including by mapping the diasporas and their skills, as a means to maintain the link between diasporas and their country of origin.

# Objective 20
## Title: Minimize the adverse drivers and structural factors that compel people to leave their country of origin
## Associated actions
- a. Promote the implementation of the 2030 Agenda for Sustainable Development, including the Sustainable Development Goals and the Addis Ababa Action Agenda, and the commitment to reach the furthest behind first, as well as the Paris Agreement4 and the Sendai Framework for Disaster Risk Reduction 2015-2030.
- b. Invest in programmes that accelerate States' fulfilment of the Sustainable Development Goals with the aim of eliminating the adverse drivers and structural factors that compel people to leave their country of origin, including through poverty eradication, food security, health and sanitation, education, inclusive economic growth, infrastructure, urban and rural development, employment creation, decent work, gender equality and empowerment of women and girls, resilience and disaster risk reduction, climate change mitigation and adaptation, addressing the socioeconomic effects of all forms of violence, non-discrimination, rule of law and good governance access to justice and protection of human rights, as well as creating and maintaining peaceful and inclusive societies with effective, accountable and transparent institutions.
- c. Establish or strengthen mechanisms to monitor and anticipate the development of risks and threats that might trigger or affect migration movements, strengthen early warning systems, develop emergency procedures and toolkits, launch emergency operations, and support post-emergency recovery, in close cooperation with and support of other States, relevant national and local authorities, National Human Rights Institutions, and civil society.
- d. Invest in sustainable development at local and national levels in all regions allowing all people to improve their lives and meet their aspirations, by fostering sustained, inclusive and sustainable economic growth, including through private and foreign direct investment and trade preferences, to create conducive conditions that allow communities and individuals to take advantage of opportunities in their own countries and drive sustainable development.
- e. Invest in human capital development by promoting entrepreneurship, education, vocational training and skills development programmes and partnerships, productive employment creation, in line with labour market needs, as well as in cooperation with the private sector and trade unions, with a view to reducing youth unemployment, avoiding brain drain and optimizing brain gain in countries of origin, and harnessing the demographic dividend.
- f. Strengthen collaboration between humanitarian and development actors, including by promoting joint analysis, multi-donor approaches and multi-year funding cycles, in order to develop long-term responses and outcomes that ensure respect for the rights of affected individuals,resilience and coping capacities of populations, as well as economic and social self-reliance, and by ensuring these efforts take migration into account.
- g. Account for migrants in national emergency preparedness and response, including by taking into consideration relevant recommendations from State-led consultative processes, such as the Guidelines to Protect Migrants in Countries Experiencing Conflict or Natural Disaster (MICIC Guidelines),
- h. Strengthen joint analysis and sharing of information to better map, understand, predict and address migration movements, such as those that may result from sudden-onset and slow onset natural disasters, the adverse effects of climate change, environmental degradation, as well as other precarious situations, while ensuring the effective respect, protection and fulfilment of the human rights of all migrants.
- i. Develop adaptation and resilience strategies to sudden-onset and slow-onset natural disasters, the adverse effects of climate change, and environmental degradation, such as desertification, land degradation, drought and sea level rise, taking into account the potential implications on migration, while recognizing that adaptation in the country of origin is a priority.
- j. Integrate displacement considerations into disaster preparedness strategies and promote cooperation with neighbouring and other relevant countries to prepare for early warning, contingency planning, stockpiling, coordination mechanisms, evacuation planning, reception and assistance arrangements, and public information.
- k. Harmonize and develop approaches and mechanisms at subregional and regional levels to address the vulnerabilities of persons affected by sudden-onset and slow-onset natural disasters, by ensuring they have access to humanitarian assistance that meets their essential needs with full respect for their rights wherever they are, and by promoting sustainable outcomes that increase resilience and self-reliance, taking into account the capacities of all countries involved.
- l. Develop coherent approaches to address the challenges of migration movements in the context of sudden-onset and slow-onset natural disasters, including by taking into consideration relevant recommendations from State-led consultative processes, such as the Agenda for the Protection of Cross-Border Displaced Persons in the Context of Disasters and Climate Change, and the Platform on Disaster Displacement.

# Objective 21
## Title: Cooperate In Facilitating Safe And Dignified Return And Readmission, As Well As Sustainable Reintegration
## Associated actions
- a. Develop and implement bilateral, regional and multilateral cooperation frameworks and agreements, including readmission agreements, ensuring that return and readmission of migrants to their own country is safe, dignified and in full compliance with international human rights law, including the rights of the child, by determining clear and mutually agreed procedures that uphold procedural safeguards, guarantee individual assessments and legal certainty, and by ensuring they also include provisions that facilitate sustainable reintegration.
- b. Promote gender-responsive and child-sensitive return and reintegration programmes, that may include legal, social and financial support, guaranteeing that all returns in the context of such voluntary programmes effectively take place on the basis of the migrant's free, prior and informed consent, and that returning migrants are assisted in their reintegration process through effective partnerships, including to avoid they become displaced in the country of origin upon return.
- c. Cooperate on identification of nationals and issuance of travel documents for safe and dignified return and readmission in cases of persons that do not have the legal right to stay on another State's territory, by establishing reliable and efficient means of identification of own nationals such as through the addition of biometric identifiers in population registries, and by digitalizing civil registry systems, with full respect to the right to privacy and protection of personal data.
- d. Foster institutional contacts between consular authorities and relevant officials from countries of origin and destination, and provide adequate consular assistance to returning migrants prior to return by facilitating access to documentation, travel documents, and other services, in order to ensure predictability, safety and dignity in return and readmission.
- e. Ensure that the return of migrants who do not have the legal right to stay on another State's territory is safe and dignified, follows an individual assessment, is carried out by competent authorities through prompt and effective cooperation between countries of origin and destination, and allows all applicable legal remedies to be exhausted, in compliance with due process guarantees, and other obligations under international human rights law.
- f. Establish or strengthen national monitoring mechanisms on return, in partnership with relevant stakeholders, that provide independent recommendations on ways and means to strengthen accountability, in order to guarantee the safety, dignity, and human rights of all returning migrants.
- g. Ensure that return and readmission processes involving children are carried out only after a determination of the best interests of the child, take into account the right to family life, family unity, and that a parent, legal guardian or specialized official accompanies the child throughout the return process, ensuring that appropriate reception, care and reintegration arrangements for children are in place in the country of origin upon return.
- h. Facilitate the sustainable reintegration of returning migrants into community life by providing them equal access to social protection and services, justice, psycho-social assistance, vocational training, employment opportunities and decent work, recognition of skills acquired abroad, and financial services, in order to fully build upon their entrepreneurship, skills and human capital as active members of society and contributors to sustainable development in the country of origin upon return.
- i. Identify and address the needs of the communities to which migrants return including corresponding provisions in national and local development strategies, infrastructure planning, budget allocations and other relevant policy decisions and cooperating with local authorities and relevant stakeholders.

# Objective 22
## Title: Establish Mechanisms For The Portability Of Social Security Entitlements And Earned Benefits
## Associated actions
- a. Establish or maintain non-discriminatory national social protection systems, including social protection floors for nationals and migrants, in line with the ILO Recommendation 202 on Social Protection Floors.
- b. Conclude reciprocal bilateral, regional or multilateral social security agreements on the portability of earned benefits for migrant workers at all skills levels, which refer to applicable social protection floors in the respective States, applicable social security entitlements and provisions, such as pensions, healthcare or other earned benefits, or integrate such provisions into other relevant agreements, such as those on long-term and temporary labour migration.
- c. Integrate provisions on the portability of entitlements and earned benefits into national social security frameworks, designate focal points in countries of origin, transit and destination that facilitate portability requests from migrants, address the difficulties women and older persons can face in accessing social protection, and establish dedicated instruments, such as migrant welfare funds in countries of origin that support migrant workers and their families.

# Objective 23
## Title: Strengthen International Cooperation And Global Partnerships For Safe, Orderly And Regular Migration
## Associated actions
- a. Support other States as we collectively implement the Global Compact, including through the provision of financial and technical assistance, in line with national priorities, policies action plans and strategies, through a whole-of-government and whole-of-society approach.
- b. Increase international and regional cooperation to accelerate the implementation of the 2030 Agenda for Sustainable Development in geographic areas from where irregular migration systematically originates due to consistent impacts of poverty, unemployment, climate change and disasters, inequality, corruption, poor governance, among other structural factors, through appropriate cooperation frameworks, innovative partnerships and the involvement of all relevant stakeholders, while upholding national ownership and shared responsibility.
- c. Involve and support local authorities in the identification of needs and opportunities for international cooperation for the effective implementation of the Global Compact and integrate their perspectives and priorities into development strategies, programmes and planning on migration, as a means to ensure good governance as well as policy coherence across levels of government and policy sectors, and maximize the effectiveness and impact of international development cooperation.
- d. Make use of the capacity-building mechanism and build upon other existing instruments to strengthen the capacities of relevant authorities by mobilizing technical, financial and human resources from States international financial institutions, the private sector, international organizations and other sources in order to assist all States in fulfilling the commitments outlined in this Global Compact.
- e. Conclude bilateral, regional or multilateral mutually beneficial, tailored and transparent partnerships, in line with international law, that develop targeted solutions to migration policy issues of common interest and address opportunities and challenges of migration in accordance with the Global Compact.
